#!/bin/sh

set -e

arkime-wise-start
if ! systemctl is-active -q arkimewise; then
    echo "FAILURE: arkimewise service is not active"
    exit 1
fi

arkime-wise-stop

# do not test arkime-parliament-start, it requires previous
# configuration and OpenSearch/Elasticsearch running
